@@ -16,29 +16,24 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+"""Main unit tests for pycoast."""
 
 import os
 import unittest
+from glob import glob
 
 import numpy as np
 from PIL import Image, ImageFont
 import time
 
 
-def tmp(f):
-    f.tmp = True
-    return f
-
-
 def fft_proj_rms(a1, a2):
-    """Compute the RMS of differences between FFT vectors of a1
-    and projection of FFT vectors of a2.
+    """Compute the RMS of differences between FFT vectors of a1 and projection of FFT vectors of a2.
+
     This metric is sensitive to large scale changes and image noise but
     insensitive to small rendering differences.
     """
-
     ms = 0
-
     for i in range(3):
         fr1 = np.fft.fft2(a1[:, :, i])
         fr2 = np.fft.fft2(a2[:, :, i])
@@ -50,8 +45,8 @@ def fft_proj_rms(a1, a2):
         p2 = np.arctan2(fr2.imag, fr2.real)
 
         theta = p2 - p1
-        l = ps2 * np.cos(theta)
-        ms += ((l - ps1) ** 2).sum() / float(ps1.size)
+        adjusted_ps2 = ps2 * np.cos(theta)
+        ms += ((adjusted_ps2 - ps1) ** 2).sum() / float(ps1.size)
 
     rms = np.sqrt(ms)
 
@@ -59,9 +54,7 @@ def fft_proj_rms(a1, a2):
 
 
 def fft_metric(data1, data2, max_value=0.1):
-    """Execute FFT metric
-    """
-
+    """Execute FFT metric."""
     rms = fft_proj_rms(data1, data2)
     return rms <= max_value
 
@@ -73,6 +66,7 @@ p_file_coasts = 'test_coasts_p_mode.png'
 
 
 class TestPycoast(unittest.TestCase):
+    """Base class for test classes that need example images."""
 
     def setUp(self):
         img = Image.new('RGB', (640, 480))
@@ -88,6 +82,7 @@ class TestPycoast(unittest.TestCase):
 
 
 class TestPIL(TestPycoast):
+    """Test PIL-based contour writer."""
 
     def test_europe(self):
         from pycoast import ContourWriterPIL
@@ -342,11 +337,11 @@ class TestPIL(TestPycoast):
                 (-39, 63.5), (-55 + 4 / 6.0, 63.5), (-57 + 45 / 60.0, 65),
                 (-76, 76), (-75, 78), (-60, 82), (0, 90),
                 (30, 82), (0, 82), (0, 73), (-20, 73), (-20, 70)),
-            'REYKJAVIK_ATC':   (
+            'REYKJAVIK_ATC': (
                 (0.0, 73.0), (0.0, 61.0), (-30.0, 61.0), (-39, 63.5),
                 (-55 + 4 / 6.0, 63.5), (-57 + 45 / 60.0, 65),
                 (-76, 76), (-75, 78), (-60, 82), (0, 90), (30, 82), (0, 82)),
-            'ICELAND_BOX':     ((-25, 62.5), (-25, 67), (-13, 67), (-13, 62.5))
+            'ICELAND_BOX': ((-25, 62.5), (-25, 67), (-13, 67), (-13, 62.5))
         }
 
         cw.add_polygon(img, area_def, polygons['REYKJAVIK_ATC'], outline='red')
@@ -482,6 +477,7 @@ class TestPIL(TestPycoast):
 
 
 class TestPILAGG(TestPycoast):
+    """Test AGG contour writer."""
 
     def test_europe_agg(self):
         from pycoast import ContourWriterAGG
@@ -852,7 +848,7 @@ class TestPILAGG(TestPycoast):
         self.assertTrue(image_mode == 'RGBA', 'Conversion to RGBA failed.')
 
 
-class FakeAreaDef():
+class FakeAreaDef:
     """A fake area definition object."""
 
     def __init__(self, proj4_string, area_extent, x_size, y_size):
@@ -863,7 +859,7 @@ class FakeAreaDef():
         self.area_id = 'fakearea'
 
 
-class TestFromConfig(TestPycoast):
+class TestFromConfig:
     """Test burning overlays from a config file."""
 
     def test_foreground(self):
@@ -883,8 +879,7 @@ class TestFromConfig(TestPycoast):
         img = cw.add_overlay_from_config(config_file, area_def)
 
         res = np.array(img)
-        self.assertTrue(fft_metric(euro_data, res),
-                        'Writing of contours failed')
+        assert fft_metric(euro_data, res), 'Writing of contours failed'
 
         overlays = {'coasts': {'level': [1, 2, 3, 4], 'resolution': 'l'},
                     'borders': {'outline': (255, 0, 0), 'resolution': 'c'},
@@ -892,17 +887,71 @@ class TestFromConfig(TestPycoast):
 
         img = cw.add_overlay_from_dict(overlays, area_def)
         res = np.array(img)
-        self.assertTrue(fft_metric(euro_data, res),
-                        'Writing of contours failed')
+        assert fft_metric(euro_data, res), 'Writing of contours failed'
 
-    def test_cache(self):
+    def test_cache(self, tmpdir):
         """Test generating a transparent foreground and cache it."""
         from pycoast import ContourWriterPIL
-        from tempfile import gettempdir
         euro_img = Image.open(os.path.join(os.path.dirname(__file__),
                                            'contours_europe_alpha.png'))
         euro_data = np.array(euro_img)
 
+        proj4_string = \
+            '+proj=stere +lon_0=8.00 +lat_0=50.00 +lat_ts=50.00 +ellps=WGS84'
+        area_extent = (-3363403.31, -2291879.85, 2630596.69, 2203620.1)
+        area_def = FakeAreaDef(proj4_string, area_extent, 640, 480)
+        cw = ContourWriterPIL(gshhs_root_dir)
+
+        overlays = {'cache': {'file': os.path.join(tmpdir, 'pycoast_cache')},
+                    'coasts': {'level': 4, 'resolution': 'l'},
+                    'borders': {'outline': (255, 0, 0), 'resolution': 'c'},
+                    'rivers': {'outline': 'blue', 'resolution': 'c', 'level': 5}}
+
+        # Create the original cache file
+        img = cw.add_overlay_from_dict(overlays, area_def)
+        res = np.array(img)
+        cache_glob = glob(os.path.join(tmpdir, 'pycoast_cache_*.png'))
+        assert len(cache_glob) == 1
+        cache_filename = cache_glob[0]
+        assert fft_metric(euro_data, res), 'Writing of contours failed'
+        assert os.path.isfile(cache_filename)
+        mtime = os.path.getmtime(cache_filename)
+
+        # Reuse the generated cache file
+        img = cw.add_overlay_from_dict(overlays, area_def)
+        res = np.array(img)
+        assert fft_metric(euro_data, res), 'Writing of contours failed'
+        assert os.path.isfile(cache_filename)
+        assert os.path.getmtime(cache_filename) == mtime
+
+        # Regenerate cache file
+        current_time = time.time()
+        cw.add_overlay_from_dict(overlays, area_def, current_time)
+        mtime = os.path.getmtime(cache_filename)
+        assert mtime > current_time
+        assert fft_metric(euro_data, res), 'Writing of contours failed'
+
+        cw.add_overlay_from_dict(overlays, area_def, current_time)
+        assert os.path.getmtime(cache_filename) == mtime
+        assert fft_metric(euro_data, res), 'Writing of contours failed'
+        overlays['cache']['regenerate'] = True
+        cw.add_overlay_from_dict(overlays, area_def)
+
+        assert os.path.getmtime(cache_filename) != mtime
+        assert fft_metric(euro_data, res), 'Writing of contours failed'
+
+        overlays.pop('cache')
+        overlays['grid'] = {'outline': (255, 255, 255), 'outline_opacity': 175,
+                            'minor_outline': (200, 200, 200), 'minor_outline_opacity': 127,
+                            'width': 1.0, 'minor_width': 0.5, 'minor_is_tick': True,
+                            'write_text': True, 'lat_placement': 'lr', 'lon_placement': 'b'}
+        cw.add_overlay_from_dict(overlays, area_def)
+        os.remove(cache_filename)
+
+    def test_caching_with_param_changes(self, tmpdir):
+        """Testing caching when changing parameters."""
+        from pycoast import ContourWriterPIL
+
         # img = Image.new('RGB', (640, 480))
         proj4_string = \
             '+proj=stere +lon_0=8.00 +lat_0=50.00 +lat_ts=50.00 +ellps=WGS84'
@@ -910,56 +959,47 @@ class TestFromConfig(TestPycoast):
         area_def = FakeAreaDef(proj4_string, area_extent, 640, 480)
         cw = ContourWriterPIL(gshhs_root_dir)
 
-        tmp = gettempdir()
-
-        overlays = {'cache': {'file': os.path.join(tmp, 'pycoast_cache')},
-                    'coasts': {'level': 4, 'resolution': 'l'},
-                    'borders': {'outline': (255, 0, 0), 'resolution': 'c'},
-                    'rivers': {'outline': 'blue', 'resolution': 'c', 'level': 5}}
+        font = ImageFont.truetype(os.path.join(
+            os.path.dirname(__file__), 'test_data', 'DejaVuSerif.ttf'))
+        overlays = {'cache': {'file': os.path.join(tmpdir, 'pycoast_cache')},
+                    'grid': {'font': font}}
 
         # Create the original cache file
-        cache_filename = os.path.join(tmp, 'pycoast_cache_fakearea.png')
-        img = cw.add_overlay_from_dict(overlays, area_def)
-        res = np.array(img)
-        self.assertTrue(fft_metric(euro_data, res),
-                        'Writing of contours failed')
-        self.assertTrue(os.path.isfile(cache_filename))
+        cw.add_overlay_from_dict(overlays, area_def)
+        cache_glob = glob(os.path.join(tmpdir, 'pycoast_cache_*.png'))
+        assert len(cache_glob) == 1
+        cache_filename = cache_glob[0]
+        assert os.path.isfile(cache_filename)
         mtime = os.path.getmtime(cache_filename)
 
         # Reuse the generated cache file
-        img = cw.add_overlay_from_dict(overlays, area_def)
-        res = np.array(img)
-        self.assertTrue(fft_metric(euro_data, res),
-                        'Writing of contours failed')
-        self.assertTrue(os.path.isfile(cache_filename))
-        self.assertEqual(os.path.getmtime(cache_filename), mtime)
-
-        # Regenerate cache file
-        current_time = time.time()
-        cw.add_overlay_from_dict(overlays, area_def, current_time)
-        mtime = os.path.getmtime(cache_filename)
-        self.assertGreater(mtime, current_time)
-        self.assertTrue(fft_metric(euro_data, res),
-                        'Writing of contours failed')
-
-        cw.add_overlay_from_dict(overlays, area_def, current_time)
-        self.assertEqual(os.path.getmtime(cache_filename), mtime)
-        self.assertTrue(fft_metric(euro_data, res),
-                        'Writing of contours failed')
-        overlays['cache']['regenerate'] = True
         cw.add_overlay_from_dict(overlays, area_def)
+        cache_glob = glob(os.path.join(tmpdir, 'pycoast_cache_*.png'))
+        assert len(cache_glob) == 1
+        assert os.path.isfile(cache_filename)
+        assert os.path.getmtime(cache_filename) == mtime
 
-        self.assertNotEqual(os.path.getmtime(cache_filename), mtime)
-        self.assertTrue(fft_metric(euro_data, res),
-                        'Writing of contours failed')
+        # Remove the font option, should produce the same result
+        # font is not considered when caching
+        del overlays['grid']['font']
+        cw.add_overlay_from_dict(overlays, area_def)
+        cache_glob = glob(os.path.join(tmpdir, 'pycoast_cache_*.png'))
+        assert len(cache_glob) == 1
+        assert os.path.isfile(cache_filename)
+        assert os.path.getmtime(cache_filename) == mtime
 
-        overlays.pop('cache')
-        overlays['grid'] = {'outline': (255, 255, 255), 'outline_opacity': 175,
-                            'minor_outline': (200, 200, 200), 'minor_outline_opacity': 127,
-                            'width': 1.0, 'minor_width': 0.5, 'minor_is_tick': True,
-                            'write_text': True, 'lat_placement': 'lr', 'lon_placement': 'b'}
-        img = cw.add_overlay_from_dict(overlays, area_def)
-        os.remove(os.path.join(tmp, 'pycoast_cache_fakearea.png'))
+        # Changing a parameter should create a new cache file
+        overlays = {'cache': {'file': os.path.join(tmpdir, 'pycoast_cache')},
+                    'grid': {'width': 2.0}}
+        cw.add_overlay_from_dict(overlays, area_def)
+        cache_glob = glob(os.path.join(tmpdir, 'pycoast_cache_*.png'))
+        assert len(cache_glob) == 2
+        assert os.path.isfile(cache_filename)
+        new_cache_filename = cache_glob[0] if cache_glob[0] != cache_filename else cache_glob[1]
+        # original cache file should be unchanged
+        assert os.path.getmtime(cache_filename) == mtime
+        # new cache file should be...new
+        assert os.path.getmtime(new_cache_filename) != mtime
 
     def test_get_resolution(self):
         """Get the automagical resolution computation."""
@@ -968,20 +1008,6 @@ class TestFromConfig(TestPycoast):
             '+proj=stere +lon_0=8.00 +lat_0=50.00 +lat_ts=50.00 +ellps=WGS84'
         area_extent = (-3363403.31, -2291879.85, 2630596.69, 2203620.1)
         area_def = FakeAreaDef(proj4_string, area_extent, 640, 480)
-        self.assertEqual(get_resolution_from_area(area_def), 'l')
+        assert get_resolution_from_area(area_def) == 'l'
         area_def = FakeAreaDef(proj4_string, area_extent, 6400, 4800)
-        self.assertEqual(get_resolution_from_area(area_def), 'h')
-
-
-def suite():
-    loader = unittest.TestLoader()
-    mysuite = unittest.TestSuite()
-    mysuite.addTest(loader.loadTestsFromTestCase(TestPIL))
-    mysuite.addTest(loader.loadTestsFromTestCase(TestPILAGG))
-    mysuite.addTest(loader.loadTestsFromTestCase(TestFromConfig))
-
-    return mysuite
-
-
-if __name__ == "__main__":
-    suite()
+        assert get_resolution_from_area(area_def) == 'h'
